@@ -6,6 +6,7 @@ import socket
 import datetime
 from dateutil.tz import tzlocal
 from torch.utils.tensorboard import SummaryWriter
+from math import inf
 
 
 def fun_control_init(
@@ -36,6 +37,7 @@ def fun_control_init(
     log_level=50,
     lower=None,
     max_time=1,
+    max_surrogate_points=inf,
     metric_sklearn=None,
     noise=False,
     n_points=1,
@@ -132,6 +134,8 @@ def fun_control_init(
             lower bound
         max_time (int):
             The maximum time in minutes.
+        max_surrogate_points (int):
+            The maximum number of points in the surrogate model. Default is inf.
         metric_sklearn (object):
             The metric object from the scikit-learn library. Default is None.
         noise (bool):
@@ -234,6 +238,7 @@ def fun_control_init(
                 'k_folds': None,
                 'loss_function': None,
                 'lower': None,
+                'max_surrogate_points': 100,
                 'metric_river': None,
                 'metric_sklearn': None,
                 'metric_torch': None,
@@ -333,6 +338,7 @@ def fun_control_init(
         "loss_function": None,
         "lower": lower,
         "max_time": max_time,
+        "max_surrogate_points": max_surrogate_points,
         "metric_river": None,
         "metric_sklearn": metric_sklearn,
         "metric_torch": None,
@@ -452,6 +458,7 @@ def surrogate_control_init(
     seed=124,
     theta_init_zero=True,
     var_type=None,
+    metric_factorial="canberra",
 ) -> dict:
     """Initialize surrogate_control dictionary.
 
@@ -490,6 +497,8 @@ def surrogate_control_init(
         var_type (list):
             A list containing the type of the variables. Default is None.
             Note: Will be set in the Spot class.
+        metric_factorial (str):
+            The metric to be used for the factorial design. Default is "canberra".
 
     Returns:
         surrogate_control (dict):
@@ -533,6 +542,7 @@ def surrogate_control_init(
         "seed": seed,
         "theta_init_zero": theta_init_zero,
         "var_type": var_type,
+        "metric_factorial": metric_factorial,
     }
     return surrogate_control
 
