@@ -17,7 +17,7 @@ def test_optimizer_handler_adam():
     net_light_base = NetLightRegression(l1=128, epochs=10, batch_size=BATCH_SIZE,
                                     initialization='xavier', act_fn=nn.ReLU(),
                                     optimizer='Adam', dropout_prob=0.1, lr_mult=lr_mult,
-                                    patience=5, _L_in=10, _L_out=1)
+                                    patience=5, _L_in=10, _L_out=1, _torchmetric="mean_squared_error")
     trainer = L.Trainer(max_epochs=2,  enable_progress_bar=False)
     trainer.fit(net_light_base, train_loader, val_loader)
     # Adam uses a lr which is calculated as lr=lr_mult * 0.001, so this value
@@ -34,7 +34,7 @@ def test_optimizer_handler_adadelta():
     net_light_base = NetLightRegression(l1=128, epochs=10, batch_size=BATCH_SIZE,
                                     initialization='xavier', act_fn=nn.ReLU(),
                                     optimizer='Adadelta', dropout_prob=0.1, lr_mult=lr_mult,
-                                    patience=5, _L_in=10, _L_out=1)
+                                    patience=5, _L_in=10, _L_out=1, _torchmetric="mean_squared_error")
     trainer = L.Trainer(max_epochs=2,  enable_progress_bar=False)
     trainer.fit(net_light_base, train_loader, val_loader)
     # Adadelta uses a lr which is calculated as lr=lr_mult * 1.0, so this value
